@@ -1,7 +1,7 @@
 /*
    XGServerEvent - Window/Event code for X11 backends.
 
-   Copyright (C) 1998,1999 Free Software Foundation, Inc.
+   Copyright (C) 1998-2015 Free Software Foundation, Inc.
 
    Written by:  Adam Fedor <fedor@boulder.colorado.edu>
    Date: Nov 1998
@@ -89,8 +89,6 @@ static KeySym _help_keysyms[2];
 static BOOL _is_keyboard_initialized = NO;
 static BOOL _mod_ignore_shift = NO;
 
-static BOOL next_event_is_a_keyrepeat;
-
 void __objc_xgcontextevent_linking (void)
 {
 }
@@ -129,7 +127,8 @@ XGErrorHandler(Display *display, XErrorEvent *err)
 }
 
 static NSEvent*process_key_event (XEvent* xEvent, XGServer* ctxt, 
-  NSEventType eventType, NSMutableArray *event_queue);
+                                  NSEventType eventType, 
+                                  NSMutableArray *event_queue, BOOL keyRepeat);
 
 static unichar process_char (KeySym keysym, unsigned *eventModifierFlags);
 
@@ -334,9 +333,9 @@ posixFileDescriptor: (NSPosixFileDescriptor*)fileDescriptor
 {
   static int clickCount = 1;
   static unsigned int eventFlags;
+  static NSPoint eventLocation;
   NSEvent *e = nil;
   XEvent xEvent;
-  static NSPoint eventLocation;
   NSWindow *nswin;
   Window xWin;
   NSEventType eventType;
@@ -635,7 +634,7 @@ posixFileDescriptor: (NSPosixFileDescriptor*)fileDescriptor
                     (SubstructureRedirectMask | SubstructureNotifyMask), 
                     &xEvent);
                 }
-#ifdef HAVE_LIBXEXT
+#ifdef HAVE_X11_EXTENSIONS_SYNC_H
 	      else if ((Atom)xEvent.xclient.data.l[0]
 		== generic.net_wm_sync_request_atom)
 		{
@@ -1020,8 +1019,6 @@ posixFileDescriptor: (NSPosixFileDescriptor*)fileDescriptor
         NSDebugLLog(@"NSEvent", @"%lu Expose\n",
                     xEvent.xexpose.window);
         {
-          BOOL isSubWindow = NO;
-
           if (cWin == 0 || xEvent.xexpose.window != cWin->ident)
             {
               generic.cachedWindow
@@ -1029,6 +1026,8 @@ posixFileDescriptor: (NSPosixFileDescriptor*)fileDescriptor
             }
           // sub-window ?
 	  /*
+          BOOL isSubWindow = NO;
+
             {
               Window xw;
               xw = xEvent.xexpose.window;
@@ -1065,7 +1064,7 @@ posixFileDescriptor: (NSPosixFileDescriptor*)fileDescriptor
               NSDebugLLog(@"NSEvent", @"Expose frame %d %d %d %d\n",
                           rectangle.x, rectangle.y,
                           rectangle.width, rectangle.height);
-#if 1
+#if 0
               // ignore backing if sub-window
               [self _addExposedRectangle: rectangle : cWin->number : isSubWindow];
 
@@ -1195,24 +1194,59 @@ posixFileDescriptor: (NSPosixFileDescriptor*)fileDescriptor
                     xEvent.xgravity.window);
         break;
 
-            // a key has been pressed
+        // a key has been pressed
       case KeyPress:
         NSDebugLLog(@"NSEvent", @"%lu KeyPress\n",
                     xEvent.xkey.window);
         [self setLastTime: xEvent.xkey.time];
-        e = process_key_event (&xEvent, self, NSKeyDown, event_queue);
+        e = process_key_event (&xEvent, self, NSKeyDown, event_queue, NO);
         break;
 
-            // a key has been released
+        // a key has been released
       case KeyRelease:
         NSDebugLLog(@"NSEvent", @"%lu KeyRelease\n",
                     xEvent.xkey.window);
         [self setLastTime: xEvent.xkey.time];
-        e = process_key_event (&xEvent, self, NSKeyUp, event_queue);
+
+        /*
+          For key repeats X creates two corresponding KeyRelease/KeyPress events.
+          So, first we check for the KeyRelease event, take a look at the next
+          event in the queue and look if they are a matching KeyRelease/KeyPress
+          pair. If so, we ignore the current KeyRelease event.
+        */
+        if (XEventsQueued(dpy, QueuedAfterReading))
+          {
+            XEvent nev;
+            XPeekEvent(dpy, &nev);
+
+            if (nev.type == KeyPress && 
+                nev.xkey.window == xEvent.xkey.window &&
+                nev.xkey.time == xEvent.xkey.time &&
+                nev.xkey.keycode == xEvent.xkey.keycode)
+              {
+                // Ignore the current KeyRelease event.
+              }
+            else
+              {
+                /*
+                if (nev.type == ClientMessage)
+                  {
+                    NSDebugLLog(@"NSEvent", @"Next event ClientMessage type %ld %s",
+                                xEvent.xclient.message_type, 
+                                XGetAtomName(dpy, xEvent.xclient.message_type));
+                  }
+                */
+                e = process_key_event(&xEvent, self, NSKeyUp, event_queue, NO);
+              }
+          }
+        else
+          {
+            e = process_key_event(&xEvent, self, NSKeyUp, event_queue, NO);
+          }
         break;
 
-            // reports the state of the keyboard when pointer or
-            // focus enters a window
+        // reports the state of the keyboard when pointer or
+        // focus enters a window
       case KeymapNotify:
         {
           if (_is_keyboard_initialized == NO)
@@ -2014,7 +2048,7 @@ keysym_is_X_modifier (KeySym keysym)
 
 static NSEvent*
 process_key_event (XEvent* xEvent, XGServer* context, NSEventType eventType,
-  NSMutableArray *event_queue)
+                   NSMutableArray *event_queue, BOOL keyRepeat)
 {
   NSString *keys, *ukeys;
   KeySym keysym;
@@ -2031,8 +2065,6 @@ process_key_event (XEvent* xEvent, XGServer* context, NSEventType eventType,
   int alt_key = 0;
   int help_key = 0;
   KeySym modKeysym;  // process modifier independently of shift, etc.
-  XEvent next_event;
-  BOOL keyRepeat = NO;
   
   if (_is_keyboard_initialized == NO)
     initialize_keyboard ();
@@ -2181,34 +2213,6 @@ process_key_event (XEvent* xEvent, XGServer* context, NSEventType eventType,
     }
 
 
-    /*
-    For key repeats X creates two corresponding KeyRelease/KeyPress events.
-    So, first we check for the KeyRelease event, take a look at the next
-    event in the queue and look if they are a matching KeyRelease/KeyPress
-    pair. If so, we mark the current KeyRelease event as a KeyRepeat, and
-    set "next_event_is_a_keyrepeat" to "YES" so that we know that the next
-    event is a repeat too.
-    */
-  if ( next_event_is_a_keyrepeat == YES )
-    {
-        keyRepeat = YES;
-        next_event_is_a_keyrepeat = NO;
-    }
-  else if( XEventsQueued( [context xDisplay], QueuedAfterReading ) )
-    {
-      XPeekEvent( [context xDisplay], &next_event );
-      if( next_event.type == KeyPress &&
-          next_event.xkey.window == xEvent->xkey.window &&
-          next_event.xkey.keycode == xEvent->xkey.keycode &&
-          next_event.xkey.time == xEvent->xkey.time )
-        {
-          // Do not report anything for this event
-          keyRepeat = YES;
-          next_event_is_a_keyrepeat = YES;
-        }
-    }
-
-
   if (help_key)
     {
       unicode = NSHelpFunctionKey;
